@@ -16,4 +16,13 @@ shinyServer(function(input, output) {
       dyOptions(drawGrid = input$showgrid)
   })
   
+  output$from <- renderText({
+    if (!is.null(input$dygraph_date_window))
+      strftime(input$dygraph_date_window[[1]], "%d %b %Y")      
+  })
+  
+  output$to <- renderText({
+    if (!is.null(input$dygraph_date_window))
+      strftime(input$dygraph_date_window[[2]], "%d %b %Y")
+  })  
 })
